@@ -19,16 +19,58 @@
 #include "common.hpp"
 #include "config.hpp"
 
+#ifdef ENABLE_NLS
+namespace
+{
+	// obby gettext catalog
+	net6::gettext_package* local_package = NULL;
+}
+#endif
+
+extern "C"
+{
+
 const char* obby_version()
 {
 	return PACKAGE_VERSION;
 }
 
+const char* obby_codename()
+{
+	return "firenze";
+}
+
+const char* obby_package()
+{
+	return PACKAGE;
+}
+
+const char* obby_localedir()
+{
+	return LOCALEDIR;
+}
+
 #ifdef WITH_HOWL
 /* This is an entry point for which external scripts could check. */
-extern "C" void obby_has_howl()
+void obby_has_howl()
 {
 	return;
 }
 #endif
+}
 
+void obby::init_gettext(net6::gettext_package& package)
+{
+#ifdef ENABLE_NLS
+	local_package = &package;
+#endif
+}
+
+const char* obby::_(const char* msgid)
+{
+#ifdef ENABLE_NLS
+	return local_package->gettext(msgid);
+#else
+	return msgid;
+#endif
+}
